==> dpdk_17.11.10.orig.tar.xz: dpdk-stable-17.11.10/drivers/crypto/zuc/rte_zuc_pmd_private.h <==
/*-
 *   BSD LICENSE
 *
 *   Copyright(c) 2016-2017 Intel Corporation. All rights reserved.
 *
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 *     * Neither the name of Intel Corporation nor the names of its
 *       contributors may be used to endorse or promote products derived
 *       from this software without specific prior written permission.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _RTE_ZUC_PMD_PRIVATE_H_
#define _RTE_ZUC_PMD_PRIVATE_H_

#include <sso_zuc.h>

#define CRYPTODEV_NAME_ZUC_PMD		crypto_zuc
/**< KASUMI PMD device name */

#define ZUC_LOG_ERR(fmt, args...) \
	RTE_LOG(ERR, CRYPTODEV, "[%s] %s() line %u: " fmt "\n",  \
			RTE_STR(CRYPTODEV_NAME_ZUC_PMD), \
			__func__, __LINE__, ## args)

#ifdef RTE_LIBRTE_ZUC_DEBUG
#define ZUC_LOG_INFO(fmt, args...) \
	RTE_LOG(INFO, CRYPTODEV, "[%s] %s() line %u: " fmt "\n", \
			RTE_STR(CRYPTODEV_NAME_ZUC_PMD), \
			__func__, __LINE__, ## args)

#define ZUC_LOG_DBG(fmt, args...) \
	RTE_LOG(DEBUG, CRYPTODEV, "[%s] %s() line %u: " fmt "\n", \
			RTE_STR(CRYPTODEV_NAME_ZUC_PMD), \
			__func__, __LINE__, ## args)
#else
#define ZUC_LOG_INFO(fmt, args...)
#define ZUC_LOG_DBG(fmt, args...)
#endif

#define ZUC_IV_KEY_LENGTH 16
#define ZUC_DIGEST_LENGTH 4

/** private data structure for each virtual ZUC device */
struct zuc_private {
	unsigned max_nb_queue_pairs;
	/**< Max number of queue pairs supported by device */
	unsigned max_nb_sessions;
	/**< Max number of sessions supported by device */
};

/** ZUC buffer queue pair */
struct zuc_qp {
	uint16_t id;
	/**< Queue Pair Identifier */
	char name[RTE_CRYPTODEV_NAME_LEN];
	/**< Unique Queue Pair Name */
	struct rte_ring *processed_ops;
	/**< Ring for placing processed ops */
	struct rte_mempool *sess_mp;
	/**< Session Mempool */
	struct rte_cryptodev_stats qp_stats;
	/**< Queue pair statistics */
	uint8_t temp_digest[ZUC_DIGEST_LENGTH];
	/**< Buffer used to store the digest generated
	 * by the driver when verifying a digest provided
	 * by the user (using authentication verify operation)
	 */
} __rte_cache_aligned;

enum zuc_operation {
	ZUC_OP_ONLY_CIPHER,
	ZUC_OP_ONLY_AUTH,
	ZUC_OP_CIPHER_AUTH,
	ZUC_OP_AUTH_CIPHER,
	ZUC_OP_NOT_SUPPORTED
};

/** ZUC private session structure */
struct zuc_session {
	enum zuc_operation op;
	enum rte_crypto_auth_operation auth_op;
	uint8_t pKey_cipher[ZUC_IV_KEY_LENGTH];
	uint8_t pKey_hash[ZUC_IV_KEY_LENGTH];
	uint16_t cipher_iv_offset;
	uint16_t auth_iv_offset;
} __rte_cache_aligned;


extern int
zuc_set_session_parameters(struct zuc_session *sess,
		const struct rte_crypto_sym_xform *xform);


/** device specific operations function pointer structure */
extern struct rte_cryptodev_ops *rte_zuc_pmd_ops;



#endif /* _RTE_ZUC_PMD_PRIVATE_H_ */

==> dpdk_18.11.11.orig.tar.xz: dpdk-stable-18.11.11/drivers/crypto/zuc/rte_zuc_pmd_private.h <==
/* SPDX-License-Identifier: BSD-3-Clause
 * Copyright(c) 2016-2018 Intel Corporation
 */

#ifndef _RTE_ZUC_PMD_PRIVATE_H_
#define _RTE_ZUC_PMD_PRIVATE_H_

#include <sso_zuc.h>

#define CRYPTODEV_NAME_ZUC_PMD		crypto_zuc
/**< ZUC PMD device name */

/** ZUC PMD LOGTYPE DRIVER */
extern int zuc_logtype_driver;
#define ZUC_LOG(level, fmt, ...)  \
	rte_log(RTE_LOG_ ## level, zuc_logtype_driver,  \
			"%s()... line %u: " fmt "\n", __func__, __LINE__,  \
				## __VA_ARGS__)

#define ZUC_IV_KEY_LENGTH 16
#define ZUC_DIGEST_LENGTH 4

/** private data structure for each virtual ZUC device */
struct zuc_private {
	unsigned max_nb_queue_pairs;
	/**< Max number of queue pairs supported by device */
};

/** ZUC buffer queue pair */
struct zuc_qp {
	uint16_t id;
	/**< Queue Pair Identifier */
	char name[RTE_CRYPTODEV_NAME_MAX_LEN];
	/**< Unique Queue Pair Name */
	struct rte_ring *processed_ops;
	/**< Ring for placing processed ops */
	struct rte_mempool *sess_mp;
	/**< Session Mempool */
	struct rte_cryptodev_stats qp_stats;
	/**< Queue pair statistics */
	uint8_t temp_digest[ZUC_DIGEST_LENGTH];
	/**< Buffer used to store the digest generated
	 * by the driver when verifying a digest provided
	 * by the user (using authentication verify operation)
	 */
} __rte_cache_aligned;

enum zuc_operation {
	ZUC_OP_ONLY_CIPHER,
	ZUC_OP_ONLY_AUTH,
	ZUC_OP_CIPHER_AUTH,
	ZUC_OP_AUTH_CIPHER,
	ZUC_OP_NOT_SUPPORTED
};

/** ZUC private session structure */
struct zuc_session {
	enum zuc_operation op;
	enum rte_crypto_auth_operation auth_op;
	uint8_t pKey_cipher[ZUC_IV_KEY_LENGTH];
	uint8_t pKey_hash[ZUC_IV_KEY_LENGTH];
	uint16_t cipher_iv_offset;
	uint16_t auth_iv_offset;
} __rte_cache_aligned;


extern int
zuc_set_session_parameters(struct zuc_session *sess,
		const struct rte_crypto_sym_xform *xform);


/** device specific operations function pointer structure */
extern struct rte_cryptodev_ops *rte_zuc_pmd_ops;



#endif /* _RTE_ZUC_PMD_PRIVATE_H_ */
